You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@guacamole.apache.org by jm...@apache.org on 2016/08/10 23:50:45 UTC

[1/3] incubator-guacamole-client git commit: GUACAMOLE-5: Define connection and sharing profile parameters separately.

Repository: incubator-guacamole-client
Updated Branches:
  refs/heads/master 8f18b49b0 -> 4929f8da2


GUACAMOLE-5: Define connection and sharing profile parameters separately.


Project: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/commit/14365ff7
Tree: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/tree/14365ff7
Diff: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/diff/14365ff7

Branch: refs/heads/master
Commit: 14365ff72ec6490ae876d5c6c5c63a5a7f070620
Parents: 989ad39
Author: Michael Jumper <mj...@apache.org>
Authored: Sun Aug 7 22:50:26 2016 -0700
Committer: Michael Jumper <mj...@apache.org>
Committed: Sun Aug 7 22:50:26 2016 -0700

----------------------------------------------------------------------
 .../guacamole/protocols/ProtocolInfo.java       | 115 +++++++++++++++----
 .../org/apache/guacamole/protocols/rdp.json     |   2 +-
 .../org/apache/guacamole/protocols/ssh.json     |   2 +-
 .../org/apache/guacamole/protocols/telnet.json  |   2 +-
 .../org/apache/guacamole/protocols/vnc.json     |   2 +-
 .../app/manage/templates/manageConnection.html  |   2 +-
 .../src/main/webapp/app/rest/types/Protocol.js  |  16 ++-
 7 files changed, 108 insertions(+), 33 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/14365ff7/guacamole-ext/src/main/java/org/apache/guacamole/protocols/ProtocolInfo.java
----------------------------------------------------------------------
diff --git a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/rdp.json b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/rdp.json
index c768d50..9ff5d51 100644
--- a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/rdp.json
+++ b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/rdp.json
@@ -1,6 +1,6 @@
 {
     "name"  : "rdp",
-    "forms" : [
+    "connectionForms" : [
 
         {
             "name"  : "network",

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/14365ff7/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/ssh.json
----------------------------------------------------------------------
diff --git a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/ssh.json b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/ssh.json
index 1f75db2..36e3a0e 100644
--- a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/ssh.json
+++ b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/ssh.json
@@ -1,6 +1,6 @@
 {
     "name"  : "ssh",
-    "forms" : [
+    "connectionForms" : [
 
         {
             "name"  : "network",

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/14365ff7/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/telnet.json
----------------------------------------------------------------------
diff --git a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/telnet.json b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/telnet.json
index b33a289..2a4f9dd 100644
--- a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/telnet.json
+++ b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/telnet.json
@@ -1,6 +1,6 @@
 {
     "name"  : "telnet",
-    "forms" : [
+    "connectionForms" : [
 
         {
             "name"  : "network",

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/14365ff7/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/vnc.json
----------------------------------------------------------------------
diff --git a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/vnc.json b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/vnc.json
index 5a9a572..76222e8 100644
--- a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/vnc.json
+++ b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/vnc.json
@@ -1,6 +1,6 @@
 {
     "name"  : "vnc",
-    "forms" : [
+    "connectionForms" : [
 
         {
             "name"  : "network",

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/14365ff7/guacamole/src/main/webapp/app/manage/templates/manageConnection.html
----------------------------------------------------------------------
diff --git a/guacamole/src/main/webapp/app/manage/templates/manageConnection.html b/guacamole/src/main/webapp/app/manage/templates/manageConnection.html
index 2bf0fad..336530d 100644
--- a/guacamole/src/main/webapp/app/manage/templates/manageConnection.html
+++ b/guacamole/src/main/webapp/app/manage/templates/manageConnection.html
@@ -47,7 +47,7 @@
     <h2 class="header">{{'MANAGE_CONNECTION.SECTION_HEADER_PARAMETERS' | translate}}</h2>
     <div class="section connection-parameters" ng-class="{loading: !parameters}">
         <guac-form namespace="getNamespace(connection.protocol)"
-                   content="protocols[connection.protocol].forms"
+                   content="protocols[connection.protocol].connectionForms"
                    model="parameters"></guac-form>
     </div>
 

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/14365ff7/guacamole/src/main/webapp/app/rest/types/Protocol.js
----------------------------------------------------------------------
diff --git a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/rdp.json b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/rdp.json
index 9ff5d51..cfe51d6 100644
--- a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/rdp.json
+++ b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/rdp.json
@@ -106,6 +106,11 @@
                     "name"    : "resize-method",
                     "type"    : "ENUM",
                     "options" : [ "", "reconnect", "display-update" ]
+                },
+                {
+                    "name"    : "read-only",
+                    "type"    : "BOOLEAN",
+                    "options" : [ "true" ]
                 }
             ]
         },
@@ -280,5 +285,19 @@
             ]
         }
 
+    ],
+    "sharingProfileForms" : [
+
+        {
+            "name"  : "display",
+            "fields" : [
+                {
+                    "name"    : "read-only",
+                    "type"    : "BOOLEAN",
+                    "options" : [ "true" ]
+                }
+            ]
+        }
+
     ]
 }

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/94ce151f/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/ssh.json
----------------------------------------------------------------------
diff --git a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/ssh.json b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/ssh.json
index 36e3a0e..93cef92 100644
--- a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/ssh.json
+++ b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/ssh.json
@@ -54,6 +54,11 @@
                     "name"  : "font-size",
                     "type"  : "ENUM",
                     "options" : [ "", "8", "9", "10", "11", "12", "14", "18", "24", "30", "36", "48", "60", "72", "96" ]
+                },
+                {
+                    "name"    : "read-only",
+                    "type"    : "BOOLEAN",
+                    "options" : [ "true" ]
                 }
             ]
         },
@@ -117,5 +122,19 @@
             ]
         }
 
+    ],
+    "sharingProfileForms" : [
+
+        {
+            "name"  : "display",
+            "fields" : [
+                {
+                    "name"    : "read-only",
+                    "type"    : "BOOLEAN",
+                    "options" : [ "true" ]
+                }
+            ]
+        }
+
     ]
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/94ce151f/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/telnet.json
----------------------------------------------------------------------
diff --git a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/telnet.json b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/telnet.json
index 2a4f9dd..ea9c9fa 100644
--- a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/telnet.json
+++ b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/telnet.json
@@ -50,6 +50,11 @@
                     "name"  : "font-size",
                     "type"  : "ENUM",
                     "options" : [ "", "8", "9", "10", "11", "12", "14", "18", "24", "30", "36", "48", "60", "72", "96" ]
+                },
+                {
+                    "name"    : "read-only",
+                    "type"    : "BOOLEAN",
+                    "options" : [ "true" ]
                 }
             ]
         },
@@ -92,5 +97,19 @@
             ]
         }
 
+    ],
+    "sharingProfileForms" : [
+
+        {
+            "name"  : "display",
+            "fields" : [
+                {
+                    "name"    : "read-only",
+                    "type"    : "BOOLEAN",
+                    "options" : [ "true" ]
+                }
+            ]
+        }
+
     ]
 }

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/94ce151f/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/vnc.json
----------------------------------------------------------------------
diff --git a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/vnc.json b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/vnc.json
index 76222e8..4d42f55 100644
--- a/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/vnc.json
+++ b/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/vnc.json
@@ -150,5 +150,19 @@
             ]
         }
 
+    ],
+    "sharingProfileForms" : [
+
+        {
+            "name"  : "display",
+            "fields" : [
+                {
+                    "name"    : "read-only",
+                    "type"    : "BOOLEAN",
+                    "options" : [ "true" ]
+                }
+            ]
+        }
+
     ]
 }

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/94ce151f/guacamole/src/main/webapp/translations/de.json
----------------------------------------------------------------------
diff --git a/guacamole/src/main/webapp/translations/de.json b/guacamole/src/main/webapp/translations/de.json
index fd30030..67c8a15 100644
--- a/guacamole/src/main/webapp/translations/de.json
+++ b/guacamole/src/main/webapp/translations/de.json
@@ -292,6 +292,7 @@
         "FIELD_HEADER_INITIAL_PROGRAM" : "Startprogramm:",
         "FIELD_HEADER_PASSWORD"        : "Passwort:",
         "FIELD_HEADER_PORT"            : "Port:",
+        "FIELD_HEADER_READ_ONLY"       : "Nur-Lesen:",
         "FIELD_HEADER_REMOTE_APP_ARGS" : "Parameter:",
         "FIELD_HEADER_REMOTE_APP_DIR"  : "Arbeitsverzeichnis:",
         "FIELD_HEADER_REMOTE_APP"      : "Programm:",
@@ -354,6 +355,7 @@
         "FIELD_HEADER_PASSPHRASE"  : "Passphrase:",
         "FIELD_HEADER_PORT"        : "Port:",
         "FIELD_HEADER_PRIVATE_KEY" : "Privater Schl�ssel:",
+        "FIELD_HEADER_READ_ONLY"   : "Nur-Lesen:",
 
         "FIELD_OPTION_COLOR_SCHEME_BLACK_WHITE" : "Schwarz auf Wei�",
         "FIELD_OPTION_COLOR_SCHEME_EMPTY"       : "",
@@ -397,6 +399,7 @@
         "FIELD_HEADER_PASSWORD"       : "Passwort:",
         "FIELD_HEADER_PASSWORD_REGEX" : "Regul�re Passwortersetzungen:",
         "FIELD_HEADER_PORT"           : "Port:",
+        "FIELD_HEADER_READ_ONLY"      : "Nur-Lesen:",
 
         "FIELD_OPTION_COLOR_SCHEME_BLACK_WHITE" : "Schwarz auf Wei�",
         "FIELD_OPTION_COLOR_SCHEME_EMPTY"       : "",

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/94ce151f/guacamole/src/main/webapp/translations/en.json
----------------------------------------------------------------------
diff --git a/guacamole/src/main/webapp/translations/en.json b/guacamole/src/main/webapp/translations/en.json
index e991436..01f332e 100644
--- a/guacamole/src/main/webapp/translations/en.json
+++ b/guacamole/src/main/webapp/translations/en.json
@@ -304,6 +304,7 @@
         "FIELD_HEADER_PORT"            : "Port:",
         "FIELD_HEADER_PRECONNECTION_BLOB" : "Preconnection BLOB (VM ID):",
         "FIELD_HEADER_PRECONNECTION_ID"   : "RDP source ID:",
+        "FIELD_HEADER_READ_ONLY"      : "Read-only:",
         "FIELD_HEADER_RECORDING_NAME" : "Recording name:",
         "FIELD_HEADER_RECORDING_PATH" : "Recording path:",
         "FIELD_HEADER_RESIZE_METHOD" : "Resize method:",
@@ -378,6 +379,7 @@
         "FIELD_HEADER_PASSPHRASE"  : "Passphrase:",
         "FIELD_HEADER_PORT"        : "Port:",
         "FIELD_HEADER_PRIVATE_KEY" : "Private key:",
+        "FIELD_HEADER_READ_ONLY"   : "Read-only:",
         "FIELD_HEADER_RECORDING_NAME" : "Recording name:",
         "FIELD_HEADER_RECORDING_PATH" : "Recording path:",
         "FIELD_HEADER_TYPESCRIPT_NAME" : "Typescript name:",
@@ -429,6 +431,7 @@
         "FIELD_HEADER_PASSWORD"       : "Password:",
         "FIELD_HEADER_PASSWORD_REGEX" : "Password regular expression:",
         "FIELD_HEADER_PORT"           : "Port:",
+        "FIELD_HEADER_READ_ONLY"      : "Read-only:",
         "FIELD_HEADER_RECORDING_NAME" : "Recording name:",
         "FIELD_HEADER_RECORDING_PATH" : "Recording path:",
         "FIELD_HEADER_TYPESCRIPT_NAME" : "Typescript name:",

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/94ce151f/guacamole/src/main/webapp/translations/fr.json
----------------------------------------------------------------------
diff --git a/guacamole/src/main/webapp/translations/fr.json b/guacamole/src/main/webapp/translations/fr.json
index 2fc9abd..b219997 100644
--- a/guacamole/src/main/webapp/translations/fr.json
+++ b/guacamole/src/main/webapp/translations/fr.json
@@ -294,6 +294,7 @@
         "FIELD_HEADER_PORT"            : "Port:",
         "FIELD_HEADER_PRECONNECTION_BLOB" : "Pr�-connexion BLOB (VM ID):",
         "FIELD_HEADER_PRECONNECTION_ID"   : "Source RDP ID:",
+        "FIELD_HEADER_READ_ONLY"       : "Lecture seule:",
         "FIELD_HEADER_REMOTE_APP_ARGS" : "Param�tres:",
         "FIELD_HEADER_REMOTE_APP_DIR"  : "R�pertoire de travail:",
         "FIELD_HEADER_REMOTE_APP"      : "Programme:",
@@ -357,6 +358,7 @@
         "FIELD_HEADER_PASSPHRASE"  : "Phrase secr�te:",
         "FIELD_HEADER_PORT"        : "Port:",
         "FIELD_HEADER_PRIVATE_KEY" : "Cl� priv�e:",
+        "FIELD_HEADER_READ_ONLY"   : "Lecture seule:",
 
         "FIELD_OPTION_COLOR_SCHEME_BLACK_WHITE" : "Noir sur blanc",
         "FIELD_OPTION_COLOR_SCHEME_EMPTY"       : "",
@@ -400,6 +402,7 @@
         "FIELD_HEADER_PASSWORD"       : "Mot de passe:",
         "FIELD_HEADER_PASSWORD_REGEX" : "Expression r�guli�re Mot de passe:",
         "FIELD_HEADER_PORT"           : "Port:",
+        "FIELD_HEADER_READ_ONLY"      : "Lecture seule:",
 
         "FIELD_OPTION_COLOR_SCHEME_BLACK_WHITE" : "Noir sur blanc",
         "FIELD_OPTION_COLOR_SCHEME_EMPTY"       : "",

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/94ce151f/guacamole/src/main/webapp/translations/nl.json
----------------------------------------------------------------------
diff --git a/guacamole/src/main/webapp/translations/nl.json b/guacamole/src/main/webapp/translations/nl.json
index 1438145..413ebbd 100644
--- a/guacamole/src/main/webapp/translations/nl.json
+++ b/guacamole/src/main/webapp/translations/nl.json
@@ -295,6 +295,7 @@
         "FIELD_HEADER_PORT"            : "Poort:",
         "FIELD_HEADER_PRECONNECTION_BLOB" : "Voor te bereiden BLOB (VM ID):",
         "FIELD_HEADER_PRECONNECTION_ID"   : "RDP bron ID:",
+        "FIELD_HEADER_READ_ONLY"      : "Alleen lezen:",
         "FIELD_HEADER_RECORDING_NAME" : "Opname naam:",
         "FIELD_HEADER_RECORDING_PATH" : "Opname map:",
         "FIELD_HEADER_RESIZE_METHOD" : "Schaal methode:",
@@ -369,6 +370,7 @@
         "FIELD_HEADER_PASSPHRASE"  : "Wachtwoordzin:",
         "FIELD_HEADER_PORT"        : "Poort:",
         "FIELD_HEADER_PRIVATE_KEY" : "Persoonlijke sleutel:",
+        "FIELD_HEADER_READ_ONLY"   : "Alleen lezen:",
         "FIELD_HEADER_RECORDING_NAME" : "Opname naam:",
         "FIELD_HEADER_RECORDING_PATH" : "Opname map:",
         "FIELD_HEADER_TYPESCRIPT_NAME" : "Typescript naam:",
@@ -420,6 +422,7 @@
         "FIELD_HEADER_PASSWORD"       : "Wachtwoord:",
         "FIELD_HEADER_PASSWORD_REGEX" : "Wachtwoord reguliere expressie:",
         "FIELD_HEADER_PORT"           : "Poort:",
+        "FIELD_HEADER_READ_ONLY"      : "Alleen lezen:",
         "FIELD_HEADER_RECORDING_NAME" : "Opname naam:",
         "FIELD_HEADER_RECORDING_PATH" : "Opname map:",
         "FIELD_HEADER_TYPESCRIPT_NAME" : "Typescript naam:",

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/94ce151f/guacamole/src/main/webapp/translations/ru.json
----------------------------------------------------------------------
diff --git a/guacamole/src/main/webapp/translations/ru.json b/guacamole/src/main/webapp/translations/ru.json
index a391240..8f2ef69 100644
--- a/guacamole/src/main/webapp/translations/ru.json
+++ b/guacamole/src/main/webapp/translations/ru.json
@@ -271,6 +271,7 @@
         "FIELD_HEADER_INITIAL_PROGRAM" : "\u0417\u0430\u043f\u0443\u0441\u043a \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c \u043f\u0440\u0438 \u043f\u043e\u0434\u043a\u043b\u044e\u0447\u0435\u043d\u0438\u0438:",
         "FIELD_HEADER_PASSWORD"        : "\u041f\u0430\u0440\u043e\u043b\u044c:",
         "FIELD_HEADER_PORT"            : "\u041f\u043e\u0440\u0442:",
+        "FIELD_HEADER_READ_ONLY"       : "\u0422\u043e\u043b\u044c\u043a\u043e \u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440:",
         "FIELD_HEADER_REMOTE_APP_ARGS" : "\u041f\u0430\u0440\u0430\u043c\u0435\u0442\u0440\u044b RemoteApp:",
         "FIELD_HEADER_REMOTE_APP_DIR"  : "\u0420\u0430\u0431\u043e\u0447\u0438\u0439 \u043a\u0430\u0442\u0430\u043b\u043e\u0433 RemoteApp:",
         "FIELD_HEADER_REMOTE_APP"      : "\u041f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u044b RemoteApp:",
@@ -322,6 +323,7 @@
         "FIELD_HEADER_PASSPHRASE"  : "\u0421\u0435\u043a\u0440\u0435\u0442\u043d\u0430\u044f \u0444\u0440\u0430\u0437\u0430:",
         "FIELD_HEADER_PORT"        : "\u041f\u043e\u0440\u0442:",
         "FIELD_HEADER_PRIVATE_KEY" : "\u041f\u0440\u0438\u0432\u0430\u0442\u043d\u044b\u0439 \u043a\u043b\u044e\u0447:",
+        "FIELD_HEADER_READ_ONLY"   : "\u0422\u043e\u043b\u044c\u043a\u043e \u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440:",
 
         "FIELD_OPTION_FONT_SIZE_8"     : "8",
         "FIELD_OPTION_FONT_SIZE_9"     : "9",
@@ -352,6 +354,7 @@
         "FIELD_HEADER_PASSWORD"       : "\u041f\u0430\u0440\u043e\u043b\u044c:",
         "FIELD_HEADER_PASSWORD_REGEX" : "\u0420\u0435\u0433\u0443\u043b\u044f\u0440\u043d\u043e\u0435 \u0432\u044b\u0440\u0430\u0436\u0435\u043d\u0438\u0435 \u0434\u043b\u044f \u043f\u0430\u0440\u043e\u043b\u044f:",
         "FIELD_HEADER_PORT"           : "\u041f\u043e\u0440\u0442:",
+        "FIELD_HEADER_READ_ONLY"      : "\u0422\u043e\u043b\u044c\u043a\u043e \u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440:",
 
         "FIELD_OPTION_FONT_SIZE_8"     : "8",
         "FIELD_OPTION_FONT_SIZE_9"     : "9",


[3/3] incubator-guacamole-client git commit: GUACAMOLE-5: Merge sharing connection, sharing profile parameter addition.

Posted by jm...@apache.org.
GUACAMOLE-5: Merge sharing connection, sharing profile parameter addition.


Project: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/commit/4929f8da
Tree: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/tree/4929f8da
Diff: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/diff/4929f8da

Branch: refs/heads/master
Commit: 4929f8da2b809c6ea75b79a9efab519d974010fa
Parents: 8f18b49 94ce151
Author: James Muehlner <ja...@guac-dev.org>
Authored: Wed Aug 10 16:49:57 2016 -0700
Committer: James Muehlner <ja...@guac-dev.org>
Committed: Wed Aug 10 16:49:57 2016 -0700

----------------------------------------------------------------------
 .../guacamole/protocols/ProtocolInfo.java       | 115 +++++++++++++++----
 .../org/apache/guacamole/protocols/rdp.json     |  21 +++-
 .../org/apache/guacamole/protocols/ssh.json     |  21 +++-
 .../org/apache/guacamole/protocols/telnet.json  |  21 +++-
 .../org/apache/guacamole/protocols/vnc.json     |  16 ++-
 .../app/manage/templates/manageConnection.html  |   2 +-
 .../src/main/webapp/app/rest/types/Protocol.js  |  16 ++-
 guacamole/src/main/webapp/translations/de.json  |   3 +
 guacamole/src/main/webapp/translations/en.json  |   3 +
 guacamole/src/main/webapp/translations/fr.json  |   3 +
 guacamole/src/main/webapp/translations/nl.json  |   3 +
 guacamole/src/main/webapp/translations/ru.json  |   3 +
 12 files changed, 194 insertions(+), 33 deletions(-)
----------------------------------------------------------------------
diff --git a/guacamole-ext/src/main/java/org/apache/guacamole/protocols/ProtocolInfo.java b/guacamole-ext/src/main/java/org/apache/guacamole/protocols/ProtocolInfo.java
index ec33231..a5a8aa6 100644
--- a/guacamole-ext/src/main/java/org/apache/guacamole/protocols/ProtocolInfo.java
+++ b/guacamole-ext/src/main/java/org/apache/guacamole/protocols/ProtocolInfo.java
@@ -24,9 +24,10 @@ import java.util.Collection;
 import org.apache.guacamole.form.Form;
 
 /**
- * Describes a protocol and all forms associated with it, as required by
- * a protocol plugin for guacd. This class allows known forms for a
- * protocol to be exposed to the user as friendly fields.
+ * Describes a protocol and all parameters associated with it, as required by
+ * a protocol plugin for guacd. Each parameter is described with a Form, which
+ * allows the parameters of a protocol to be exposed to the user as friendly
+ * groupings of fields.
  *
  * @author Michael Jumper
  */
@@ -38,15 +39,45 @@ public class ProtocolInfo {
     private String name;
 
     /**
-     * A collection of all associated protocol forms.
+     * A collection of forms describing all known parameters for a connection
+     * using this protocol.
      */
-    private Collection<Form> forms;
+    private Collection<Form> connectionForms;
+
+    /**
+     * A collection of forms describing all known parameters relevant to a
+     * sharing profile whose primary connection uses this protocol.
+     */
+    private Collection<Form> sharingProfileForms;
+
+    /**
+     * Creates a new ProtocolInfo having the given name and forms. The given
+     * collections of forms are used to describe the parameters for connections
+     * and sharing profiles respectively.
+     *
+     * @param name
+     *     The unique name associated with the protocol.
+     *
+     * @param connectionForms
+     *     A collection of forms describing all known parameters for a
+     *     connection using this protocol.
+     *
+     * @param sharingProfileForms
+     *     A collection of forms describing all known parameters relevant to a
+     *     sharing profile whose primary connection uses this protocol.
+     */
+    public ProtocolInfo(String name, Collection<Form> connectionForms,
+            Collection<Form> sharingProfileForms) {
+        this.name = name;
+        this.connectionForms = connectionForms;
+        this.sharingProfileForms = sharingProfileForms;
+    }
 
     /**
      * Creates a new ProtocolInfo with no associated name or forms.
      */
     public ProtocolInfo() {
-        this.forms = new ArrayList<Form>();
+        this(null);
     }
 
     /**
@@ -56,22 +87,24 @@ public class ProtocolInfo {
      *     The unique name associated with the protocol.
      */
     public ProtocolInfo(String name) {
-        this.name  = name;
-        this.forms = new ArrayList<Form>();
+        this(name, new ArrayList<Form>());
     }
 
     /**
      * Creates a new ProtocolInfo having the given name and forms.
      *
      * @param name
      *     The unique name associated with the protocol.
      *
      * @param forms
-     *     The forms to associate with the protocol.
+     *     A collection of forms describing all known parameters for this
+     *     protocol, regardless of whether it is used in the context of a
+     *     connection or a sharing profile.
      */
     public ProtocolInfo(String name, Collection<Form> forms) {
-        this.name  = name;
-        this.forms = forms;
+        this(name, forms, new ArrayList<Form>(forms));
     }
 
     /**
@@ -95,25 +128,57 @@ public class ProtocolInfo {
     }
 
     /**
      * Returns a mutable collection of the protocol forms associated with
      * this protocol. Changes to this collection affect the forms exposed
      * to the user.
      *
      * @return A mutable collection of protocol forms.
      */
-    public Collection<Form> getForms() {
-        return forms;
+    public Collection<Form> getConnectionForms() {
+        return connectionForms;
     }
 
     /**
-     * Sets the collection of protocol forms associated with this
-     * protocol.
+     * Sets the collection of forms describing all known parameters for a
+     * connection using this protocol. The provided collection must be mutable.
      *
-     * @param forms
-     *     The collection of forms to associate with this protocol.
+     * @param connectionForms
+     *     A mutable collection of forms describing all known parameters for a
+     *     connection using this protocol.
+     */
+    public void setConnectionForms(Collection<Form> connectionForms) {
+        this.connectionForms = connectionForms;
+    }
+
+    /**
+     * Returns a mutable collection of forms describing all known parameters
+     * relevant to a sharing profile whose primary connection uses this
+     * protocol. Changes to this collection affect the forms exposed to the
+     * user.
+     *
+     * @return
+     *     A mutable collection of forms describing all known parameters
+     *     relevant to a sharing profile whose primary connection uses this
+     *     protocol.
      */
-    public void setForms(Collection<Form> forms) {
-        this.forms = forms;
+    public Collection<Form> getSharingProfileForms() {
+        return sharingProfileForms;
     }
-    
+
+    /**
+     * Sets the collection of forms describing all known parameters relevant to
+     * a sharing profile whose primary connection uses this protocol. The
+     * provided collection must be mutable.
+     *
+     * @param sharingProfileForms
+     *     A mutable collection of forms describing all known parameters
+     *     relevant to a sharing profile whose primary connection uses this
+     *     protocol.
+     */
+    public void setSharingProfileForms(Collection<Form> sharingProfileForms) {
+        this.sharingProfileForms = sharingProfileForms;
+    }
+
 }

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/14365ff7/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/rdp.json
----------------------------------------------------------------------
@@ -56,22 +87,24 @@ public class ProtocolInfo {
 
     /**
-     * Creates a new ProtocolInfo having the given name and forms.
+     * Creates a new ProtocolInfo having the given name and forms. The given
+     * forms are used to describe the parameters for both connections and
+     * sharing profiles.
      *
      * @param name
@@ -95,25 +128,57 @@ public class ProtocolInfo {
 
     /**
-     * Returns a mutable collection of the protocol forms associated with
-     * this protocol. Changes to this collection affect the forms exposed
-     * to the user.
+     * Returns a mutable collection of forms describing all known parameters for
+     * a connection using this protocol. Changes to this collection affect the
+     * forms exposed to the user.
      *
@@ -95,25 +128,57 @@ public class ProtocolInfo {
      *
-     * @return A mutable collection of protocol forms.
+     * @return
+     *     A mutable collection of forms describing all known parameters for a
+     *     connection using this protocol.
      */
diff --git a/guacamole/src/main/webapp/app/rest/types/Protocol.js b/guacamole/src/main/webapp/app/rest/types/Protocol.js
index cf1298a..cfb26f0 100644
--- a/guacamole/src/main/webapp/app/rest/types/Protocol.js
+++ b/guacamole/src/main/webapp/app/rest/types/Protocol.js
@@ -44,13 +44,23 @@ angular.module('rest').factory('Protocol', [function defineProtocol() {
         this.name = template.name;
 
         /**
          * An array of forms containing all known parameters for this protocol,
          * their types, and other information.
          *
          * @type Form[]
          * @default []
          */
-        this.forms = template.forms || [];
+        this.connectionForms = template.connectionForms || [];
+
+        /**
+         * An array of forms describing all known parameters relevant to a
+         * sharing profile whose primary connection uses this protocol,
+         * including their types, and other information.
+         *
+         * @type Form[]
+         * @default []
+         */
+        this.sharingProfileForms = template.sharingProfileForms || [];
 
     };
 


[2/3] incubator-guacamole-client git commit: GUACAMOLE-5: Add "read-only" parameter to all protocols.

Posted by jm...@apache.org.
GUACAMOLE-5: Add "read-only" parameter to all protocols.


Project: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/commit/94ce151f
Tree: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/tree/94ce151f
Diff: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/diff/94ce151f

Branch: refs/heads/master
Commit: 94ce151f69a7cbe5b98f86d9f7997c498955bb6c
Parents: 14365ff
Author: Michael Jumper <mj...@apache.org>
Authored: Sun Aug 7 21:21:57 2016 -0700
Committer: Michael Jumper <mj...@apache.org>
Committed: Sun Aug 7 22:53:32 2016 -0700

----------------------------------------------------------------------
 .../org/apache/guacamole/protocols/rdp.json      | 19 +++++++++++++++++++
 .../org/apache/guacamole/protocols/ssh.json      | 19 +++++++++++++++++++
 .../org/apache/guacamole/protocols/telnet.json   | 19 +++++++++++++++++++
 .../org/apache/guacamole/protocols/vnc.json      | 14 ++++++++++++++
 guacamole/src/main/webapp/translations/de.json   |  3 +++
 guacamole/src/main/webapp/translations/en.json   |  3 +++
 guacamole/src/main/webapp/translations/fr.json   |  3 +++
 guacamole/src/main/webapp/translations/nl.json   |  3 +++
 guacamole/src/main/webapp/translations/ru.json   |  3 +++
 9 files changed, 86 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-guacamole-client/blob/94ce151f/guacamole-ext/src/main/resources/org/apache/guacamole/protocols/rdp.json
----------------------------------------------------------------------
@@ -44,13 +44,23 @@ angular.module('rest').factory('Protocol', [function defineProtocol() {
 
         /**
-         * An array of forms containing all known parameters for this protocol,
-         * their types, and other information.
+         * An array of forms describing all known parameters for a connection
+         * using this protocol, including their types and other information.
          *
          * @type Form[]